@@ -139,9 +139,13 @@ def attachSettings(settingsDict, enablePaypal=False):
 
     #=========================================================================
     # Oscar default settings 
+    addOscarDefaultsPackages = {}
     oscarDefaultsPackages = __import__(
-        'oscar.defaults', globals(), locals(), [], -1).__dict__
-    update(settingsDict, oscarDefaultsPackages)
+        'oscar', globals(), locals(), [], -1).__dict__['defaults']
+    for attr in dir(oscarDefaultsPackages):
+        addOscarDefaultsPackages[attr] = getattr(
+            oscarDefaultsPackages, attr)
+    update(settingsDict, addOscarDefaultsPackages)
     #=========================================================================
 
     #=========================================================================
